package agency;

import javax.naming.*;
import javax.jms.*;

public class MessageSender {

    private QueueConnection queueConnection;
    private QueueSession queueSession;
    private QueueSender queueSender;
    private Queue queue;

    public MessageSender(String jndiFactory, String jndiQueue) throws JMSException, NamingException {
        Context context = new InitialContext();
        QueueConnectionFactory queueFactory = (QueueConnectionFactory)context.lookup(jndiFactory);
        queueConnection = queueFactory.createQueueConnection();
        queueSession = queueConnection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
        queue = (Queue)context.lookup(jndiQueue);
        queueSender = queueSession.createSender(queue);
    }

    public void sendApplicant(String applicant, boolean newApplicant) throws JMSException {
        TextMessage message = queueSession.createTextMessage();
        message.setBooleanProperty ("NewApplicant", newApplicant);
        message.setText(applicant);
        queueSender.send(message);
    }

    public void sendJob(String ref, String customer, boolean newJob) throws JMSException {
        TextMessage message = queueSession.createTextMessage();
        message.setBooleanProperty ("NewJob", newJob);
        message.setText(ref+"+"+customer);
        queueSender.send(message);
    }

    public void close() throws JMSException {
         //Send a non-text control message indicating end of messages
        queueSender.send(queueSession.createMessage());

        queueSender.close();
        queueSession.close();
        queueConnection.close();
    }
}

